@@ -1,43 +1,29 @@
 /*
-  Copyright (C) 2008-2014 by Eike Hein <hein@kde.org>
-  Copyright (C) 2020 by Ryan McCoskrie <work@ryanmccoskrie.me>
+  SPDX-FileCopyrightText: 2008-2014 Eike Hein <hein@kde.org>
+  SPDX-FileCopyrightText: 2020 Ryan McCoskrie <work@ryanmccoskrie.me>
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; either version 2 of
-  the License or (at your option) version 3 or any later version
-  accepted by the membership of KDE e.V. (or its successor appro-
-  ved by the membership of KDE e.V.), which shall act as a proxy
-  defined in Section 14 of version 3 of the license.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program. If not, see https://www.gnu.org/licenses/.
+  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-
 #include "titlebar.h"
 #include "mainwindow.h"
 #include "skin.h"
 
+#include <KLocalizedString>
 #include <QFontDatabase>
 #include <QMenu>
 #include <QPushButton>
-#include <KLocalizedString>
 
 #include <QApplication>
 #include <QBitmap>
 #include <QPainter>
 
-TitleBar::TitleBar(MainWindow* mainWindow) : QWidget(mainWindow)
+TitleBar::TitleBar(MainWindow *mainWindow)
+    : QWidget(mainWindow)
 {
     setWhatsThis(xi18nc("@info:whatsthis",
-                       "<title>Title Bar</title>"
-                       "<para>The title bar displays the session title if available.</para>"));
+                        "<title>Title Bar</title>"
+                        "<para>The title bar displays the session title if available.</para>"));
 
     setAttribute(Qt::WA_OpaquePaintEvent);
 
@@ -73,9 +59,21 @@ TitleBar::~TitleBar()
 {
 }
 
+void TitleBar::setVisible(bool visible)
+{
+    m_visible = visible;
+    if (m_visible) {
+        resize(width(), m_skin->titleBarBackgroundImage().height());
+    } else {
+        resize(width(), 0);
+    }
+
+    QWidget::setVisible(m_visible);
+}
+
 void TitleBar::applySkin()
 {
-    resize(width(), m_skin->titleBarBackgroundImage().height());
+    resize(width(), m_visible ? m_skin->titleBarBackgroundImage().height() : 0);
 
     m_focusButton->setStyleSheet(m_skin->titleBarFocusButtonStyleSheet());
     m_menuButton->setStyleSheet(m_skin->titleBarMenuButtonStyleSheet());
@@ -106,7 +104,7 @@ void TitleBar::moveButtons()
         m_quitButton->move(width() - m_skin->titleBarQuitButtonPosition().x(), m_skin->titleBarQuitButtonPosition().y());
 }
 
-void TitleBar::resizeEvent(QResizeEvent* event)
+void TitleBar::resizeEvent(QResizeEvent *event)
 {
     moveButtons();
 
@@ -115,18 +113,16 @@ void TitleBar::resizeEvent(QResizeEvent* event)
     QWidget::resizeEvent(event);
 }
 
-void TitleBar::paintEvent(QPaintEvent*)
+void TitleBar::paintEvent(QPaintEvent *)
 {
     QPainter painter(this);
     painter.setPen(m_skin->titleBarTextColor());
 
-    const QPixmap& backgroundImage = m_skin->titleBarBackgroundImage();
-    const QPixmap& leftCornerImage = m_skin->titleBarLeftCornerImage();
-    const QPixmap& rightCornerImage = m_skin->titleBarRightCornerImage();
+    const QPixmap &backgroundImage = m_skin->titleBarBackgroundImage();
+    const QPixmap &leftCornerImage = m_skin->titleBarLeftCornerImage();
+    const QPixmap &rightCornerImage = m_skin->titleBarRightCornerImage();
 
-    painter.drawTiledPixmap(leftCornerImage.width(), 0,
-                            width() - leftCornerImage.width() - rightCornerImage.width(), height(),
-                            backgroundImage);
+    painter.drawTiledPixmap(leftCornerImage.width(), 0, width() - leftCornerImage.width() - rightCornerImage.width(), height(), backgroundImage);
 
     painter.drawPixmap(0, 0, leftCornerImage);
     painter.drawPixmap(width() - rightCornerImage.width(), 0, rightCornerImage);
@@ -136,7 +132,9 @@ void TitleBar::paintEvent(QPaintEvent*)
     painter.setFont(font);
 
     const QString title = this->title();
-    if (m_skin->titleBarTextCentered() && width() > m_skin->titleBarTextPosition().x() + painter.fontMetrics().width(title) + m_focusButton->width() + m_quitButton->width() + m_menuButton->width())
+    if (m_skin->titleBarTextCentered()
+        && width()
+            > m_skin->titleBarTextPosition().x() + painter.fontMetrics().width(title) + m_focusButton->width() + m_quitButton->width() + m_menuButton->width())
         painter.drawText(0, 0, width(), height(), Qt::AlignCenter, title);
     else
         painter.drawText(m_skin->titleBarTextPosition(), title);
@@ -144,20 +142,19 @@ void TitleBar::paintEvent(QPaintEvent*)
     painter.end();
 }
 
-void TitleBar::mouseMoveEvent(QMouseEvent* event)
+void TitleBar::mouseMoveEvent(QMouseEvent *event)
 {
-    if(event->buttons() == Qt::LeftButton) {
-        //Dynamic cast needed to use getDesktopGeometry()
-        MainWindow* window = dynamic_cast<MainWindow*>( parent() );
+    if (event->buttons() == Qt::LeftButton) {
+        // Dynamic cast needed to use getDesktopGeometry()
+        MainWindow *window = dynamic_cast<MainWindow *>(parent());
 
         int maxHeight = window->getDesktopGeometry().height();
         int newHeight = event->globalY() / (maxHeight / 100);
 
-        //Correct newHeight if mouse is dragged too far
-        if(newHeight > 100) {
+        // Correct newHeight if mouse is dragged too far
+        if (newHeight > 100) {
             newHeight = 100;
-        }
-        else if(newHeight < 10) {
+        } else if (newHeight < 10) {
             newHeight = 10;
         }
 
@@ -169,16 +166,15 @@ void TitleBar::mouseMoveEvent(QMouseEvent* event)
 
 void TitleBar::updateMask()
 {
-    const QPixmap& leftCornerImage = m_skin->titleBarLeftCornerImage();
-    const QPixmap& rightCornerImage = m_skin->titleBarRightCornerImage();
+    const QPixmap &leftCornerImage = m_skin->titleBarLeftCornerImage();
+    const QPixmap &rightCornerImage = m_skin->titleBarRightCornerImage();
 
     QRegion leftCornerRegion = leftCornerImage.hasAlpha() ? QRegion(leftCornerImage.mask()) : QRegion(leftCornerImage.rect());
     QRegion rightCornerRegion = rightCornerImage.hasAlpha() ? QRegion(rightCornerImage.mask()) : QRegion(rightCornerImage.rect());
 
     QRegion mask = leftCornerRegion;
 
-    mask += QRegion(QRect(0, 0, width() - leftCornerImage.width() - rightCornerImage.width(),
-        height())).translated(leftCornerImage.width(), 0);
+    mask += QRegion(QRect(0, 0, width() - leftCornerImage.width() - rightCornerImage.width(), height())).translated(leftCornerImage.width(), 0);
 
     mask += rightCornerRegion.translated(width() - rightCornerImage.width(), 0);
 
@@ -205,7 +201,7 @@ QString TitleBar::title()
         return m_title;
 }
 
-void TitleBar::setTitle(const QString& title)
+void TitleBar::setTitle(const QString &title)
 {
     m_title = title;
 
